@@ -3,7 +3,7 @@ package Math::Base::Convert::Shortcuts;
 use vars qw($VERSION);
 use strict;
 
-$VERSION = do { my @r = (q$Revision: 0.03 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 0.04 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 # load bitmaps
 
@@ -419,7 +419,7 @@ __END__
 
 =head1 NAME
 
-Math::Base::Convert::Shortcuts
+Math::Base::Convert::Shortcuts - methods for converting powers of 2 bases
 
 =head1 DESCRIPTION
 
@@ -448,7 +448,7 @@ Michael Robinton, michael@bizsystems.com
 
 =head1 COPYRIGHT
 
-Copyright 2012, Michael Robinton
+Copyright 2012-2015, Michael Robinton
 
 This program is free software; you may redistribute it and/or modify it
 under the same terms as Perl itself.
